AISTLAB\_nitrotyper
===================

    https://www.nitrotype.com/race auto typer using python3 and cv2

    only supported 1920x1080 Resolution currently.

    winxos, AISTLAB 2017-03-17

INSTALL:
--------

pip3 install nitrotyper ## USAGE: 1. open https://www.nitrotype.com/race
using your web browser 2. open console and run **nitrotyper** command.
3. make sure the web browser is on the top layer of the desktop, enjoy
it. 4. delay parameters can control the type speed.

*Just for educational purpose, take care of yourself.*
